function eigenfaces()
% Stats:
% 1024x222
% k = 40
% Cancer cycles: 50

% 1) Cancer
% 2) Capricorn
% 3) NMF (snmf by Hoyer)
% 4) NMF (ALS with reg 0)
% 5) NMF (ALS with reg 1)
% 6) SVD

%% What algorithms to run.
runCan = 0;
runCap = 0;
runSnmf = 0;
runAls = 0;
runAlsr = 0;
runSvd = 0;

%% Parameters.
IMG_SIZE = int64(32);
PICS_PER_ROW = int64(5);
SCALE = 0.5;
N_FACES_TO_PRINT = 15;
fileName = './resultsCancer/real/eigenfaces';
experName = 'Eigenfaces';

saveCanName = './figsCancer/eigenfaces/Cancer.pdf';
saveCapName = './figsCancer/eigenfaces/Capricorn.pdf';
saveSnmfName = './figsCancer/eigenfaces/Hoyer.pdf';
saveAlsName = './figsCancer/eigenfaces/ALS.pdf';
saveAlsrName = './figsCancer/eigenfaces/ALSR.pdf';


%% Load and preprocess data.
A = YaleLeft();
A = double(A);
A = bsxfun(@rdivide, A, std(A));
A = bsxfun(@minus, A, min(A));

CANCER_CYCLES = 50; 
k = 40;

realWorldExecute(runCan, runCap, runSnmf, runAls, runAlsr, runSvd, A, k, CANCER_CYCLES, fileName, experName);

load(fileName);

% plotFaces(Bcan, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveCanName);
% plotFaces(Bcap, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveCapName);
% plotFaces(Bsnmf, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveSnmfName);
plotFaces(Bals, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveAlsName);
% plotFaces(Balsr, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveAlsrName);


end


function plotFaces(B, SCALE, IMG_SIZE, PICS_PER_ROW, N_FACES_TO_PRINT, saveName)
nFactors = min(size(B, 2), N_FACES_TO_PRINT);
B = B(:, 1:nFactors);
k = int64(size(B, 2));
B = bsxfun(@rdivide, B, mean(B));
xDim = PICS_PER_ROW * IMG_SIZE;
yDim = idivide((k-1), PICS_PER_ROW, 'ceil') * IMG_SIZE;
img = zeros(yDim, xDim);
for i = 1 : k
    row = idivide((i-1), PICS_PER_ROW, 'floor') + 1;
    col = rem((i-1), PICS_PER_ROW) + 1;
    xBegin = (col-1)*IMG_SIZE + 1;
    yBegin = (row-1)*IMG_SIZE + 1;
    xEnd = xBegin + IMG_SIZE - 1;
    yEnd = yBegin + IMG_SIZE - 1;
    newPic = reshape(B(:, i), IMG_SIZE, IMG_SIZE);
    try
        img(yBegin:yEnd, xBegin:xEnd) = newPic;
    catch
        wtf=1;
    end
end

imshow(SCALE * img);
saveas(gcf, saveName, 'pdf');
end
