function realWorldExecute(runCan, runCap, runSnmf, runAls, runAlsr, runSvd, A, k, CANCER_CYCLES, fileName, experName)
%% Run algorithms.

if runCan == 1
    [Bcan, Ccan, errorsCan] = Cancer(A, k, 'NCYCLES', CANCER_CYCLES);
    if exist(strcat(fileName, '.mat'), 'file') > 0
        save(fileName, 'Bcan', 'Ccan', 'errorsCan', '-append');
    else
        save(fileName, 'Bcan', 'Ccan', 'errorsCan');
    end
end

if runCap == 1
    [Bcap, Ccap] = Capricorn(A, k);
    save(fileName, 'Bcap', 'Ccap', '-append');
end

if runSnmf == 1
    load(fileName);
    [sB, sC] = getHoyerSparsityOfFactors(Bcan, Ccan);
    [Bsnmf, Csnmf] = HoyerWrapper(A, k, sB, sC);
    save(fileName, 'Bsnmf', 'Csnmf', '-append');
end

if runAls == 1
    [Bals, Cals] = nmf_als(A, k);
    save(fileName, 'Bals', 'Cals', '-append');
end

if runAlsr == 1
    [Balsr, Calsr] = nmf_als_reg(A, k);
    save(fileName, 'Balsr', 'Calsr', '-append');
end

if runSvd == 1
    [Bsvd, Csvd] = svdWrapper(A, k);
    save(fileName, 'Bsvd', 'Csvd', '-append');
end


%% Print errors.
load(fileName);
fprintf('\n');
fprintf('Error  %s\n', experName);

if exist('Bcan', 'var')
    error_ = norm(A - MaxProduct(Bcan, Ccan), 'fro') / norm(A, 'fro');
    fprintf('Cancer error: %f\n', error_);
end

if exist('Bcap', 'var')
    error_ = norm(A - MaxProduct(Bcap, Ccap), 'fro') / norm(A, 'fro');
    fprintf('Capricorn error: %f\n', error_);
end

if exist('Bsnmf', 'var')
    error_ = norm(A - Bsnmf*Csnmf, 'fro') / norm(A, 'fro');
    fprintf('Hoyer error: %f\n', error_);
end

if exist('Bals', 'var')
    error_ = norm(A - Bals*Cals, 'fro') / norm(A, 'fro');
    fprintf('ALS error: %f\n', error_);
end

if exist('Balsr', 'var')
    error_ = norm(A - Balsr*Calsr, 'fro') / norm(A, 'fro');
    fprintf('ALS reg error: %f\n', error_);
end

if exist('Bsvd', 'var')
    error_ = norm(A - Bsvd*Csvd, 'fro') / norm(A, 'fro');
    fprintf('SVD error: %f\n', error_);
end

fprintf('\n');


%% Print sparsity.
load(fileName);
fprintf('\n');
fprintf('Sparsity  %s\n', experName);

if exist('Bcan', 'var')
    sparsity = getSparsity(Bcan, Ccan);
    fprintf('Cancer sparsity: %f\n', sparsity);
end

if exist('Bcap', 'var')
    sparsity = getSparsity(Bcap, Ccap);
    fprintf('Capricorn sparsity: %f\n', sparsity);
end

if exist('Bsnmf', 'var')
    sparsity = getSparsity(Bsnmf, Csnmf);
    fprintf('SNMF sparsity: %f\n', sparsity);
end

if exist('Bals', 'var')
    sparsity = getSparsity(Bals, Cals);
    fprintf('ALS sparsity: %f\n', sparsity);
end

if exist('Balsr', 'var')
    sparsity = getSparsity(Balsr, Calsr);
    fprintf('ALSR sparsity: %f\n', sparsity);
end

if exist('Bsvd', 'var')
    sparsity = getSparsity(Bsvd, Csvd);
    fprintf('SVD sparsity: %f\n', sparsity);
end

fprintf('\n');


%% Data specs.
[n, m] = size(A);
density = nnz(A) / numel(A);
fprintf('Data specs  %s\n', experName);
fprintf('rows: %d\n', n);
fprintf('columns: %d\n', m);
fprintf('density: %f\n', density);
fprintf('\n');
fprintf('\n');


end