function Cplot(xMin, xInc, xIters, nInstances, dataName, ...
    canName, capName, snmfName, alsName, alsrName, svdName, alsr5Name, ...
    saveName, sparseName, addLegend, xlabelStr, ylabelStr)

saveNameFig = strcat(saveName(1:end-3), 'fig');  % Replacing .pdf with .fig
sparseNameFig = strcat(sparseName(1:end-3), 'fig');  % Replacing .pdf with .fig

% Params.
FontSize = 30;
mn = 10;
LW = 1.2;
MarkerSize = 10;
xLegendShift = 0.04;
yLegendShift = 0.02;
yLegendShiftSparse = 0.065;
% axisShift = params.inc_ / 6;


% Find xVals range.
xVals = nan(xIters, 1);
for i = 1 : xIters
    xVals(i) = xMin + (i-1)*xInc;
end

if numel(xVals) > 10
    tickInc = 3 * xInc;
else
    tickInc = 2 * xInc;
end
ticks = min(xVals) : tickInc : max(xVals);

shiftX = xInc / 10;

load(dataName);

load(canName);
load(capName);
load(snmfName);
load(alsName);
load(alsrName);
load(svdName);
load(alsr5Name);

resultsCan = nan(xIters, nInstances);
resultsCap = nan(xIters, nInstances);
resultsSnmf = nan(xIters, nInstances);
resultsAls = nan(xIters, nInstances);
resultsAlsr = nan(xIters, nInstances);
resultsSVD = nan(xIters, nInstances);
resultsAlsr5 = nan(xIters, nInstances);

%% Frobenius error
for i = 1 : xIters
    for j = 1 : nInstances
        resultsCan(i, j) = frobRelative(Aorig{i}{j}, MaxProduct(Bcan{i}{j}, Ccan{i}{j}));
        resultsCap(i, j) = frobRelative(Aorig{i}{j}, MaxProduct(Bcap{i}{j}, Ccap{i}{j}));
        resultsSnmf(i, j) = frobRelative(Aorig{i}{j}, Bsnmf{i}{j}*Csnmf{i}{j});
        resultsAls(i, j) = frobRelative(Aorig{i}{j}, Bals{i}{j}*Cals{i}{j});
        resultsAlsr(i, j) = frobRelative(Aorig{i}{j}, Balsr{i}{j}*Calsr{i}{j});
        resultsSVD(i, j) = frobRelative(Aorig{i}{j}, Bsvd{i}{j}*Csvd{i}{j});
        resultsAlsr5(i, j) = frobRelative(Aorig{i}{j}, Balsr5{i}{j}*Calsr5{i}{j});
    end
end

errorbar(xVals, mean(resultsCan, 2), std(resultsCan, 0, 2), '-xr', ...
    'LineWidth', LW, 'markers', MarkerSize);
hold on
errorbar(xVals, mean(resultsCap, 2), std(resultsCap, 0, 2), '-xc', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals, mean(resultsSnmf, 2), std(resultsSnmf, 0, 2), '-xb', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals + shiftX, mean(resultsAls, 2), std(resultsAls, 0, 2), '-xg', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals - shiftX, mean(resultsAlsr, 2), std(resultsAlsr, 0, 2), '-xm', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals + 2*shiftX, mean(resultsSVD, 2), std(resultsSVD, 0, 2), '-xk', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals, mean(resultsAlsr5, 2), std(resultsAlsr5, 0, 2), '-x', 'Color', [.7 .5 0], ...
    'LineWidth', LW, 'markers', MarkerSize);
if addLegend == 1
    h = legend('Cancer', 'Capricorn', 'SNMF', 'ALS', 'ALSR', 'SVD', 'ALSR5', 'fontsize', FontSize+30);    
    set(h,'FontSize', FontSize - mn);
    h.Position(1) = h.Position(1) + xLegendShift;
    h.Position(2) = h.Position(2) + yLegendShift;
    legend boxoff
end

xlabel(xlabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
ylabel(ylabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
set(gca,'fontsize', FontSize-8);
set(gca,'XTick', ticks);
set(gca,'XLim', [min(xVals), max(xVals)]);

axis tight
% x=input('adjust');

hold off
saveas(gcf, saveName, 'pdf');
saveas(gcf, saveNameFig, 'fig');
close all


%% Factor sparsity.
for i = 1 : xIters
    for j = 1 : nInstances
        resultsCan(i, j) = getSparsity(Bcan{i}{j}, Ccan{i}{j});
        resultsCap(i, j) = getSparsity(Bcap{i}{j}, Ccap{i}{j});
        resultsSnmf(i, j) = getSparsity(Bsnmf{i}{j}, Csnmf{i}{j});
        resultsAls(i, j) = getSparsity(Bals{i}{j}, Cals{i}{j});
        resultsAlsr(i, j) = getSparsity(Balsr{i}{j}, Calsr{i}{j}); 
        resultsAlsr5(i, j) = getSparsity(Balsr5{i}{j}, Calsr5{i}{j});
    end
end

errorbar(xVals, mean(resultsCan, 2), std(resultsCan, 0, 2), '-xr', ...
    'LineWidth', LW, 'markers', MarkerSize);
hold on
errorbar(xVals, mean(resultsCap, 2), std(resultsCap, 0, 2), '-xc', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals, mean(resultsSnmf, 2), std(resultsSnmf, 0, 2), '-xb', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals + shiftX, mean(resultsAls, 2), std(resultsAls, 0, 2), '-xg', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals - shiftX, mean(resultsAlsr, 2), std(resultsAlsr, 0, 2), '-xm', ...
    'LineWidth', LW, 'markers', MarkerSize);
errorbar(xVals, mean(resultsAlsr5, 2), std(resultsAlsr5, 0, 2), '-x', 'Color', [.7 .5 0], ...
    'LineWidth', LW, 'markers', MarkerSize);

if addLegend == 1
    h = legend('Cancer', 'Capricorn', 'SNMF', 'ALS', 'ALSR', 'ALSR5', 'fontsize', FontSize+30);    
    set(h,'FontSize', FontSize - mn);
    h.Position(1) = h.Position(1) + xLegendShift;
    h.Position(2) = h.Position(2) + yLegendShiftSparse;
    legend boxoff
end

xlabel(xlabelStr, 'interpreter', 'latex', 'fontsize', FontSize);
ylabel('Sparsity', 'interpreter', 'latex', 'fontsize', FontSize);
set(gca,'fontsize', FontSize-8);
set(gca,'XTick', ticks);
set(gca,'XLim', [min(xVals), max(xVals)]);

axis tight
% x=input('adjust');

hold off
saveas(gcf, sparseName, 'pdf');
saveas(gcf, sparseNameFig, 'fig');
close all

end


function err_ = frobRelative(A, A_)
err_ = norm(A-A_, 'fro') / norm(A, 'fro');
end





