function plotPredict(minSize, sizeInc, sizeIters, nInstances, dataName, nmfName, alsName, capName, saveName)

% Params.
FontSize = 30;
mn = 10;
LW = 1.2;
MarkerSize = 10;

% Find holdout set size range.
sizes = nan(sizeIters, 1);
for i = 1 : sizeIters
    sizes(i) = minSize + (i-1)*sizeInc;
end

load(dataName);

load(capName);
load(nmfName);

resultsCap = nan(sizeIters, nInstances);
resultsNMF = nan(sizeIters, nInstances);

for i = 1 : sizeIters
    for j = 1 : nInstances
        
        Acap = MaxProduct(Bcap{i}{j}, Ccap{i}{j});
        resultsCap(i, j) = nnz(round(Acap(H{i}{j})) == Aorig{i}{j}(H{i}{j})) / numel(Aorig{i}{j}(H{i}{j}));
        
        Anmf = Bnmf{i}{j} * Cnmf{i}{j};
        resultsNMF(i, j) = nnz(round(Anmf(H{i}{j})) == Aorig{i}{j}(H{i}{j})) / numel(Aorig{i}{j}(H{i}{j}));
    end
end
errorbar(sizes, mean(resultsCap, 2), std(resultsCap, 0, 2), '-xr', ...
    'LineWidth', LW, 'markers', MarkerSize);
hold on
errorbar(sizes, mean(resultsNMF, 2), std(resultsNMF, 0, 2), '-xb', ...
    'LineWidth', LW, 'markers', MarkerSize);

h = legend('Capricorn', 'WNMF', 'fontsize', FontSize+30);
set(h,'FontSize', FontSize - mn);
legend boxoff

xlabel('Holdout set size', 'interpreter', 'latex', 'fontsize', FontSize);
ylabel('Prediction rate', 'interpreter', 'latex', 'fontsize', FontSize);
set(gca,'fontsize', FontSize-8);

axis tight

hold off
saveas(gcf, saveName, 'pdf');
end